@@ -30,8 +30,8 @@ build_time_vars = {'ABIFLAGS': '',
            '-fexceptions   -O3',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
-                          '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
+ 'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                          '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
@@ -44,7 +44,7 @@ build_time_vars = {'ABIFLAGS': '',
                             '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                             '-fstack-protector-strong '
                             '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                            '-m64 -mcpu=power9 -mtune=power9 '
+                            '-m64 -mcpu=power9 -mtune=power10 '
                             '-fasynchronous-unwind-tables '
                             '-fstack-clash-protection  -D_GNU_SOURCE -fPIC '
                             '-fwrapv -fno-semantic-interposition -flto '
@@ -94,19 +94,19 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.12.6/build/optimized/coverage.info',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.12.9/build/optimized/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.12.6/build/optimized/lcov-report',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.12.9/build/optimized/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.12.6/Include',
+             '-I/builddir/build/BUILD/Python-3.12.9/Include',
  'CXX': 'g++',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
- 'DEEPFREEZE_DEPS': '/builddir/build/BUILD/Python-3.12.6/Tools/build/deepfreeze.py '
+ 'DEEPFREEZE_DEPS': '/builddir/build/BUILD/Python-3.12.9/Tools/build/deepfreeze.py '
                     '_bootstrap_python '
-                    '/builddir/build/BUILD/Python-3.12.6/Programs/_freeze_module.py '
+                    '/builddir/build/BUILD/Python-3.12.9/Programs/_freeze_module.py '
                     '\\',
  'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.12 '
@@ -143,13 +143,12 @@ build_time_vars = {'ABIFLAGS': '',
  'EXTRATESTOPTS': '',
  'EXT_SUFFIX': '.cpython-312-powerpc64le-linux-gnu.so',
  'FILEMODE': 644,
- 'FLOAT_WORDS_BIGENDIAN': 0,
  'FREEZE_MODULE': './_bootstrap_python '
-                  '/builddir/build/BUILD/Python-3.12.6/Programs/_freeze_module.py',
+                  '/builddir/build/BUILD/Python-3.12.9/Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
  'FREEZE_MODULE_DEPS': '_bootstrap_python '
-                       '/builddir/build/BUILD/Python-3.12.6/Programs/_freeze_module.py',
+                       '/builddir/build/BUILD/Python-3.12.9/Programs/_freeze_module.py',
  'FROZEN_FILES_IN': '\\',
  'FROZEN_FILES_OUT': '\\',
  'GETPGRP_HAVE_ARG': 0,
@@ -578,6 +577,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
+ 'HAVE_SYS_PIDFD_H': 1,
  'HAVE_SYS_POLL_H': 1,
  'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
@@ -611,7 +611,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TMPNAM_R': 1,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
- 'HAVE_TTYNAME': 1,
+ 'HAVE_TTYNAME_R': 1,
  'HAVE_TZNAME': 0,
  'HAVE_UMASK': 1,
  'HAVE_UNAME': 1,
@@ -680,7 +680,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                     '-fstack-protector-strong '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                    '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
+                    '-mcpu=power9 -mtune=power10 -fasynchronous-unwind-tables '
                     '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv '
                     '-fno-semantic-interposition -flto -fuse-linker-plugin '
                     '-ffat-lto-objects -flto-partition=none -g -std=c11 '
@@ -695,15 +695,15 @@ build_time_vars = {'ABIFLAGS': '',
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                     '-fstack-protector-strong '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                    '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
+                    '-mcpu=power9 -mtune=power10 -fasynchronous-unwind-tables '
                     '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv -O3 '
                     '-fprofile-use -fprofile-correction '
-                    '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
+                    '-I/builddir/build/BUILD/Python-3.12.9/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
-                    '-I/builddir/build/BUILD/Python-3.12.6/Include -fPIC -fPIC',
+                    '-I/builddir/build/BUILD/Python-3.12.9/Include -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
- 'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.6/Modules/_hacl/include '
+ 'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.9/Modules/_hacl/include '
                    '-D_BSD_SOURCE -D_DEFAULT_SOURCE -fno-strict-overflow '
                    '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
                    '-fexceptions -fexceptions -fexceptions   -O3 -flto=auto '
@@ -715,7 +715,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-fstack-protector-strong '
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                   '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
+                   '-mcpu=power9 -mtune=power10 -fasynchronous-unwind-tables '
                    '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv '
                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
                    '-ffat-lto-objects -flto-partition=none -g -std=c11 -Wextra '
@@ -729,12 +729,12 @@ build_time_vars = {'ABIFLAGS': '',
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-fstack-protector-strong '
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                   '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
+                   '-mcpu=power9 -mtune=power10 -fasynchronous-unwind-tables '
                    '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv -O3 '
                    '-fprofile-use -fprofile-correction '
-                   '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
+                   '-I/builddir/build/BUILD/Python-3.12.9/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.12.6/Include -fPIC -fPIC',
+                   '-I/builddir/build/BUILD/Python-3.12.9/Include -fPIC -fPIC',
  'LIBHACL_HEADERS': '\\',
  'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
  'LIBHACL_SHA2_HEADERS': '\\',
@@ -753,7 +753,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                     '-fstack-protector-strong '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                    '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
+                    '-mcpu=power9 -mtune=power10 -fasynchronous-unwind-tables '
                     '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv '
                     '-fno-semantic-interposition -flto -fuse-linker-plugin '
                     '-ffat-lto-objects -flto-partition=none -g -std=c11 '
@@ -768,12 +768,12 @@ build_time_vars = {'ABIFLAGS': '',
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                     '-fstack-protector-strong '
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                    '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
+                    '-mcpu=power9 -mtune=power10 -fasynchronous-unwind-tables '
                     '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv -O3 '
                     '-fprofile-use -fprofile-correction '
-                    '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
+                    '-I/builddir/build/BUILD/Python-3.12.9/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
-                    '-I/builddir/build/BUILD/Python-3.12.6/Include -fPIC -fPIC',
+                    '-I/builddir/build/BUILD/Python-3.12.9/Include -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
  'LIBOBJDIR': 'Python/',
@@ -804,7 +804,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.12.6/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.12.9/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'array  _asyncio  _bisect  _contextvars  _csv  _heapq  '
@@ -862,7 +862,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_BINASCII_CFLAGS': '-DUSE_ZLIB_CRC32 -DWITH_GZFILEOP',
  'MODULE_BINASCII_LDFLAGS': '-lz',
  'MODULE_BINASCII_STATE': 'yes',
- 'MODULE_CMATH_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_math.h',
+ 'MODULE_CMATH_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/_math.h',
  'MODULE_CMATH_LDFLAGS': '-lm',
  'MODULE_CMATH_STATE': 'yes',
  'MODULE_DEPS_SHARED': 'Modules/config.c',
@@ -873,7 +873,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_FCNTL_STATE': 'yes',
  'MODULE_GRP_STATE': 'yes',
  'MODULE_ITERTOOLS_LDFLAGS': '',
- 'MODULE_MATH_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_math.h',
+ 'MODULE_MATH_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/_math.h',
  'MODULE_MATH_LDFLAGS': '-lm',
  'MODULE_MATH_STATE': 'yes',
  'MODULE_MMAP_STATE': 'yes',
@@ -898,8 +898,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_TERMIOS_STATE': 'yes',
  'MODULE_TIME_LDFLAGS': '',
  'MODULE_TIME_STATE': 'yes',
- 'MODULE_UNICODEDATA_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/unicodedata_db.h '
-                            '/builddir/build/BUILD/Python-3.12.6/Modules/unicodename_db.h',
+ 'MODULE_UNICODEDATA_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/unicodedata_db.h '
+                            '/builddir/build/BUILD/Python-3.12.9/Modules/unicodename_db.h',
  'MODULE_UNICODEDATA_STATE': 'yes',
  'MODULE_XXLIMITED_35_STATE': 'yes',
  'MODULE_XXLIMITED_STATE': 'yes',
@@ -911,56 +911,56 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__ASYNCIO_STATE': 'yes',
  'MODULE__BISECT_STATE': 'yes',
  'MODULE__BLAKE2_CFLAGS': '',
- 'MODULE__BLAKE2_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2-config.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2-impl.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2b-load-sse2.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2b-load-sse41.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2b-ref.c '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2b-round.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2b.c '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s-load-sse2.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s-load-sse41.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s-load-xop.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s-ref.c '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s-round.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/impl/blake2s.c '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/_blake2/blake2module.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h',
+ 'MODULE__BLAKE2_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2-config.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2-impl.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2b-load-sse2.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2b-load-sse41.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2b-ref.c '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2b-round.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2b.c '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2s-load-sse2.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2s-load-sse41.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2s-load-xop.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2s-ref.c '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2s-round.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/impl/blake2s.c '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/_blake2/blake2module.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/hashlib.h',
  'MODULE__BLAKE2_LDFLAGS': '-lssl -lcrypto',
  'MODULE__BLAKE2_STATE': 'yes',
  'MODULE__BZ2_CFLAGS': '',
  'MODULE__BZ2_LDFLAGS': '-lbz2',
  'MODULE__BZ2_STATE': 'yes',
- 'MODULE__CODECS_CN_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_cn.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_CN_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/mappings_cn.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_CN_STATE': 'yes',
- 'MODULE__CODECS_HK_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_hk.h  '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_HK_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/mappings_hk.h  '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_HK_STATE': 'yes',
- 'MODULE__CODECS_ISO2022_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_jisx0213_pair.h '
-                                '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/alg_jisx0201.h '
-                                '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/emu_jisx0213_2000.h '
-                                '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
-                                '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_ISO2022_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                                '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/alg_jisx0201.h '
+                                '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/emu_jisx0213_2000.h '
+                                '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                                '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_ISO2022_STATE': 'yes',
- 'MODULE__CODECS_JP_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_jisx0213_pair.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/alg_jisx0201.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/emu_jisx0213_2000.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_jp.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_JP_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/mappings_jisx0213_pair.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/alg_jisx0201.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/emu_jisx0213_2000.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/mappings_jp.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_JP_STATE': 'yes',
- 'MODULE__CODECS_KR_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_kr.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_KR_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/mappings_kr.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_KR_STATE': 'yes',
  'MODULE__CODECS_LDFLAGS': '',
- 'MODULE__CODECS_TW_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/mappings_tw.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h '
-                           '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/cjkcodecs.h',
+ 'MODULE__CODECS_TW_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/mappings_tw.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/multibytecodec.h '
+                           '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/cjkcodecs.h',
  'MODULE__CODECS_TW_STATE': 'yes',
  'MODULE__COLLECTIONS_LDFLAGS': '',
  'MODULE__CONTEXTVARS_STATE': 'yes',
@@ -969,7 +969,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CRYPT_STATE': 'yes',
  'MODULE__CSV_STATE': 'yes',
  'MODULE__CTYPES_CFLAGS': '-fno-strict-overflow',
- 'MODULE__CTYPES_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_ctypes/ctypes.h',
+ 'MODULE__CTYPES_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/_ctypes/ctypes.h',
  'MODULE__CTYPES_LDFLAGS': '-L/usr/lib64/../lib64 -lffi -ldl',
  'MODULE__CTYPES_MALLOC_CLOSURE': '',
  'MODULE__CTYPES_STATE': 'yes',
@@ -987,23 +987,23 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__DBM_LDFLAGS': '-lgdbm_compat',
  'MODULE__DBM_STATE': 'yes',
  'MODULE__DECIMAL_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1',
- 'MODULE__DECIMAL_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_decimal/docstrings.h',
+ 'MODULE__DECIMAL_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/_decimal/docstrings.h',
  'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
  'MODULE__DECIMAL_STATE': 'yes',
  'MODULE__ELEMENTTREE_CFLAGS': '',
- 'MODULE__ELEMENTTREE_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/pyexpat.c',
+ 'MODULE__ELEMENTTREE_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/pyexpat.c',
  'MODULE__ELEMENTTREE_STATE': 'yes',
  'MODULE__FUNCTOOLS_LDFLAGS': '',
  'MODULE__GDBM_CFLAGS': '',
  'MODULE__GDBM_LDFLAGS': '-lgdbm',
  'MODULE__GDBM_STATE': 'yes',
  'MODULE__HASHLIB_CFLAGS': '',
- 'MODULE__HASHLIB_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h',
+ 'MODULE__HASHLIB_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/hashlib.h',
  'MODULE__HASHLIB_LDFLAGS': '-lcrypto',
  'MODULE__HASHLIB_STATE': 'yes',
  'MODULE__HEAPQ_STATE': 'yes',
- 'MODULE__IO_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.6/Modules/_io',
- 'MODULE__IO_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_io/_iomodule.h',
+ 'MODULE__IO_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.9/Modules/_io',
+ 'MODULE__IO_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/_io/_iomodule.h',
  'MODULE__IO_LDFLAGS': '',
  'MODULE__IO_STATE': 'yes',
  'MODULE__JSON_STATE': 'yes',
@@ -1012,61 +1012,61 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__LZMA_CFLAGS': '',
  'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
- 'MODULE__MD5_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h \\ '
+ 'MODULE__MD5_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/hashlib.h \\ '
                      'Modules/_hacl/Hacl_Hash_MD5.h '
                      'Modules/_hacl/Hacl_Hash_MD5.c',
  'MODULE__MD5_STATE': 'disabled',
- 'MODULE__MULTIBYTECODEC_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/cjkcodecs/multibytecodec.h',
+ 'MODULE__MULTIBYTECODEC_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/cjkcodecs/multibytecodec.h',
  'MODULE__MULTIBYTECODEC_STATE': 'yes',
- 'MODULE__MULTIPROCESSING_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.6/Modules/_multiprocessing',
+ 'MODULE__MULTIPROCESSING_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.9/Modules/_multiprocessing',
  'MODULE__MULTIPROCESSING_STATE': 'yes',
  'MODULE__OPCODE_STATE': 'yes',
  'MODULE__OPERATOR_LDFLAGS': '',
  'MODULE__PICKLE_STATE': 'yes',
- 'MODULE__POSIXSHMEM_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.6/Modules/_multiprocessing',
+ 'MODULE__POSIXSHMEM_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.9/Modules/_multiprocessing',
  'MODULE__POSIXSHMEM_LDFLAGS': '',
  'MODULE__POSIXSHMEM_STATE': 'yes',
  'MODULE__POSIXSUBPROCESS_STATE': 'yes',
  'MODULE__QUEUE_STATE': 'yes',
  'MODULE__RANDOM_STATE': 'yes',
  'MODULE__SCPROXY_STATE': 'n/a',
- 'MODULE__SHA1_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h '
+ 'MODULE__SHA1_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/hashlib.h '
                       '\\ Modules/_hacl/Hacl_Hash_SHA1.h '
                       'Modules/_hacl/Hacl_Hash_SHA1.c',
  'MODULE__SHA1_STATE': 'disabled',
- 'MODULE__SHA2_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h '
+ 'MODULE__SHA2_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/hashlib.h '
                       '\\ Modules/_hacl/libHacl_Hash_SHA2.a',
  'MODULE__SHA2_STATE': 'disabled',
- 'MODULE__SHA3_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/hashlib.h '
+ 'MODULE__SHA3_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/hashlib.h '
                       '\\ Modules/_hacl/Hacl_Hash_SHA3.h '
                       'Modules/_hacl/Hacl_Hash_SHA3.c',
  'MODULE__SHA3_STATE': 'disabled',
  'MODULE__SIGNAL_LDFLAGS': '',
- 'MODULE__SOCKET_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/socketmodule.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/addrinfo.h '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/getaddrinfo.c '
-                        '/builddir/build/BUILD/Python-3.12.6/Modules/getnameinfo.c',
+ 'MODULE__SOCKET_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/socketmodule.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/addrinfo.h '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/getaddrinfo.c '
+                        '/builddir/build/BUILD/Python-3.12.9/Modules/getnameinfo.c',
  'MODULE__SOCKET_STATE': 'yes',
- 'MODULE__SQLITE3_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite',
- 'MODULE__SQLITE3_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/connection.h '
-                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/cursor.h '
-                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/microprotocols.h '
-                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/module.h '
-                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/prepare_protocol.h '
-                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/row.h '
-                         '/builddir/build/BUILD/Python-3.12.6/Modules/_sqlite/util.h',
+ 'MODULE__SQLITE3_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.9/Modules/_sqlite',
+ 'MODULE__SQLITE3_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/_sqlite/connection.h '
+                         '/builddir/build/BUILD/Python-3.12.9/Modules/_sqlite/cursor.h '
+                         '/builddir/build/BUILD/Python-3.12.9/Modules/_sqlite/microprotocols.h '
+                         '/builddir/build/BUILD/Python-3.12.9/Modules/_sqlite/module.h '
+                         '/builddir/build/BUILD/Python-3.12.9/Modules/_sqlite/prepare_protocol.h '
+                         '/builddir/build/BUILD/Python-3.12.9/Modules/_sqlite/row.h '
+                         '/builddir/build/BUILD/Python-3.12.9/Modules/_sqlite/util.h',
  'MODULE__SQLITE3_LDFLAGS': '-lsqlite3',
  'MODULE__SQLITE3_STATE': 'yes',
  'MODULE__SRE_LDFLAGS': '',
  'MODULE__SSL_CFLAGS': '',
- 'MODULE__SSL_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl.h '
-                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl/cert.c '
-                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl/debughelpers.c '
-                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl/misc.c '
-                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl_data.h '
-                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl_data_111.h '
-                     '/builddir/build/BUILD/Python-3.12.6/Modules/_ssl_data_300.h '
-                     '/builddir/build/BUILD/Python-3.12.6/Modules/socketmodule.h',
+ 'MODULE__SSL_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/_ssl.h '
+                     '/builddir/build/BUILD/Python-3.12.9/Modules/_ssl/cert.c '
+                     '/builddir/build/BUILD/Python-3.12.9/Modules/_ssl/debughelpers.c '
+                     '/builddir/build/BUILD/Python-3.12.9/Modules/_ssl/misc.c '
+                     '/builddir/build/BUILD/Python-3.12.9/Modules/_ssl_data.h '
+                     '/builddir/build/BUILD/Python-3.12.9/Modules/_ssl_data_111.h '
+                     '/builddir/build/BUILD/Python-3.12.9/Modules/_ssl_data_300.h '
+                     '/builddir/build/BUILD/Python-3.12.9/Modules/socketmodule.h',
  'MODULE__SSL_LDFLAGS': '-lssl -lcrypto',
  'MODULE__SSL_STATE': 'yes',
  'MODULE__STATISTICS_LDFLAGS': '-lm',
@@ -1075,9 +1075,9 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__STRUCT_STATE': 'yes',
  'MODULE__SYMTABLE_LDFLAGS': '',
  'MODULE__TESTBUFFER_STATE': 'yes',
- 'MODULE__TESTCAPI_DEPS': '/builddir/build/BUILD/Python-3.12.6/Modules/_testcapi/testcapi_long.h '
-                          '/builddir/build/BUILD/Python-3.12.6/Modules/_testcapi/parts.h '
-                          '/builddir/build/BUILD/Python-3.12.6/Modules/_testcapi/util.h',
+ 'MODULE__TESTCAPI_DEPS': '/builddir/build/BUILD/Python-3.12.9/Modules/_testcapi/testcapi_long.h '
+                          '/builddir/build/BUILD/Python-3.12.9/Modules/_testcapi/parts.h '
+                          '/builddir/build/BUILD/Python-3.12.9/Modules/_testcapi/util.h',
  'MODULE__TESTCAPI_STATE': 'yes',
  'MODULE__TESTCLINIC_STATE': 'yes',
  'MODULE__TESTIMPORTMULTIPLE_STATE': 'yes',
@@ -1149,7 +1149,7 @@ build_time_vars = {'ABIFLAGS': '',
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                              '-fstack-protector-strong '
                              '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                             '-m64 -mcpu=power9 -mtune=power9 '
+                             '-m64 -mcpu=power9 -mtune=power10 '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection  -D_GNU_SOURCE -fPIC '
                              '-fwrapv -fno-semantic-interposition -flto '
@@ -1168,13 +1168,13 @@ build_time_vars = {'ABIFLAGS': '',
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                              '-fstack-protector-strong '
                              '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
-                             '-m64 -mcpu=power9 -mtune=power9 '
+                             '-m64 -mcpu=power9 -mtune=power10 '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection  -D_GNU_SOURCE -fPIC '
                              '-fwrapv -O3 -fprofile-use -fprofile-correction '
-                             '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
+                             '-I/builddir/build/BUILD/Python-3.12.9/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/builddir/build/BUILD/Python-3.12.6/Include '
+                             '-I/builddir/build/BUILD/Python-3.12.9/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
@@ -1187,7 +1187,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                      '-fstack-protector-strong '
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                     '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
+                     '-mcpu=power9 -mtune=power10 -fasynchronous-unwind-tables '
                      '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv '
                      '-fno-semantic-interposition -flto -fuse-linker-plugin '
                      '-ffat-lto-objects -flto-partition=none -g -std=c11 '
@@ -1202,10 +1202,10 @@ build_time_vars = {'ABIFLAGS': '',
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                      '-fstack-protector-strong '
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                     '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
+                     '-mcpu=power9 -mtune=power10 -fasynchronous-unwind-tables '
                      '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv '
                      '-O3 -fprofile-use -fprofile-correction '
-                     '-I/builddir/build/BUILD/Python-3.12.6/Include/internal',
+                     '-I/builddir/build/BUILD/Python-3.12.9/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
@@ -1218,7 +1218,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-fstack-protector-strong '
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                   '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
+                   '-mcpu=power9 -mtune=power10 -fasynchronous-unwind-tables '
                    '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv '
                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
                    '-ffat-lto-objects -flto-partition=none -g -std=c11 -Wextra '
@@ -1232,12 +1232,12 @@ build_time_vars = {'ABIFLAGS': '',
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-fstack-protector-strong '
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                   '-mcpu=power9 -mtune=power9 -fasynchronous-unwind-tables '
+                   '-mcpu=power9 -mtune=power10 -fasynchronous-unwind-tables '
                    '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv -O3 '
                    '-fprofile-use -fprofile-correction '
-                   '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
+                   '-I/builddir/build/BUILD/Python-3.12.9/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.12.6/Include -fPIC '
+                   '-I/builddir/build/BUILD/Python-3.12.9/Include -fPIC '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,pack-relative-relocs '
                     '-Wl,-z,now -specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
@@ -1252,7 +1252,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-Wl,--build-id=sha1 '
                     '-specs=/usr/lib/rpm/redhat/redhat-package-notes  -g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.12.6/Include',
+                '-I/builddir/build/BUILD/Python-3.12.9/Include',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 0,
  'PY_LDFLAGS': '',
@@ -1290,7 +1290,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                         '-fstack-protector-strong '
                         '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                        '-mcpu=power9 -mtune=power9 '
+                        '-mcpu=power9 -mtune=power10 '
                         '-fasynchronous-unwind-tables '
                         '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv '
                         '-fno-semantic-interposition -flto -fuse-linker-plugin '
@@ -1306,13 +1306,13 @@ build_time_vars = {'ABIFLAGS': '',
                         '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                         '-fstack-protector-strong '
                         '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  -m64 '
-                        '-mcpu=power9 -mtune=power9 '
+                        '-mcpu=power9 -mtune=power10 '
                         '-fasynchronous-unwind-tables '
                         '-fstack-clash-protection  -D_GNU_SOURCE -fPIC -fwrapv '
                         '-O3 -fprofile-use -fprofile-correction '
-                        '-I/builddir/build/BUILD/Python-3.12.6/Include/internal '
+                        '-I/builddir/build/BUILD/Python-3.12.9/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.12.6/Include -fPIC',
+                        '-I/builddir/build/BUILD/Python-3.12.9/Include -fPIC',
  'PY_SUPPORT_TIER': 2,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
@@ -1324,7 +1324,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.6/build/optimized',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.9/build/optimized',
  'SCRIPTDIR': '/usr/lib64',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1434,7 +1434,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_testcapi   Modules/_xxtestfuzz   Modules/cjkcodecs   '
             'Modules/expat   Objects   Parser   Programs   Python   '
             'Python/frozen_modules   Python/deepfreeze',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.12.6/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.12.9/Tools/gdb/libpython.py',
  'STATIC_LIBPYTHON': 0,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -1445,12 +1445,12 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.6/build/optimized '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.9/build/optimized '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.6/build/optimized '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.12.9/build/optimized '
                './python -E '
-               '/builddir/build/BUILD/Python-3.12.6/Tools/scripts/run_tests.py',
+               '/builddir/build/BUILD/Python-3.12.9/Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
@@ -1460,10 +1460,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': '/builddir/build/BUILD/Python-3.12.6/Tools/build/update_file.py',
+ 'UPDATE_FILE': '/builddir/build/BUILD/Python-3.12.9/Tools/build/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.12',
- 'VPATH': '/builddir/build/BUILD/Python-3.12.6',
+ 'VPATH': '/builddir/build/BUILD/Python-3.12.9',
  'WASM_ASSETS_DIR': './usr',
  'WASM_STDLIB': './usr/lib/python3.12/os.py',
  'WHEEL_PKG_DIR': '/usr/share/python3-wheels',
@@ -1480,9 +1480,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.12.6/build/optimized',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.12.6',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.12.9/build/optimized',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.12.9',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.12.6'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.12.9'}
